@@ -38,7 +38,7 @@ EAPI const Eo_Class *elm_actionslider_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Actionslider
  */
-EOAPI void  elm_obj_actionslider_indicator_pos_set(Elm_Actionslider_Pos pos);
+EOAPI void elm_obj_actionslider_indicator_pos_set(Elm_Actionslider_Pos pos);
 
 /**
  * @brief Get actionslider indicator position.
@@ -47,7 +47,7 @@ EOAPI void  elm_obj_actionslider_indicator_pos_set(Elm_Actionslider_Pos pos);
  *
  * @ingroup Elm_Actionslider
  */
-EOAPI Elm_Actionslider_Pos  elm_obj_actionslider_indicator_pos_get(void);
+EOAPI Elm_Actionslider_Pos elm_obj_actionslider_indicator_pos_get(void);
 
 /**
  * @brief Set actionslider magnet position.
@@ -59,7 +59,7 @@ EOAPI Elm_Actionslider_Pos  elm_obj_actionslider_indicator_pos_get(void);
  *
  * @ingroup Elm_Actionslider
  */
-EOAPI void  elm_obj_actionslider_magnet_pos_set(Elm_Actionslider_Pos pos);
+EOAPI void elm_obj_actionslider_magnet_pos_set(Elm_Actionslider_Pos pos);
 
 /**
  * @brief Get actionslider magnet position.
@@ -68,7 +68,7 @@ EOAPI void  elm_obj_actionslider_magnet_pos_set(Elm_Actionslider_Pos pos);
  *
  * @ingroup Elm_Actionslider
  */
-EOAPI Elm_Actionslider_Pos  elm_obj_actionslider_magnet_pos_get(void);
+EOAPI Elm_Actionslider_Pos elm_obj_actionslider_magnet_pos_get(void);
 
 /**
  * @brief Set actionslider enabled position. To set multiple positions as
@@ -81,7 +81,7 @@ EOAPI Elm_Actionslider_Pos  elm_obj_actionslider_magnet_pos_get(void);
  *
  * @ingroup Elm_Actionslider
  */
-EOAPI void  elm_obj_actionslider_enabled_pos_set(Elm_Actionslider_Pos pos);
+EOAPI void elm_obj_actionslider_enabled_pos_set(Elm_Actionslider_Pos pos);
 
 /**
  * @brief Get actionslider enabled position.
@@ -90,28 +90,16 @@ EOAPI void  elm_obj_actionslider_enabled_pos_set(Elm_Actionslider_Pos pos);
  *
  * @ingroup Elm_Actionslider
  */
-EOAPI Elm_Actionslider_Pos  elm_obj_actionslider_enabled_pos_get(void);
+EOAPI Elm_Actionslider_Pos elm_obj_actionslider_enabled_pos_get(void);
 
 /** Get actionslider selected label.
  *
  * @ingroup Elm_Actionslider
  */
-EOAPI const char * elm_obj_actionslider_selected_label_get(void);
+EOAPI const char *elm_obj_actionslider_selected_label_get(void);
 
-EOAPI extern const Eo_Event_Description _ELM_ACTIONSLIDER_EVENT_LANGUAGE_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_ACTIONSLIDER_EVENT_ACCESS_CHANGED;
 EOAPI extern const Eo_Event_Description _ELM_ACTIONSLIDER_EVENT_POS_CHANGED;
 
-/**
- * No description
- */
-#define ELM_ACTIONSLIDER_EVENT_LANGUAGE_CHANGED (&(_ELM_ACTIONSLIDER_EVENT_LANGUAGE_CHANGED))
-
-/**
- * No description
- */
-#define ELM_ACTIONSLIDER_EVENT_ACCESS_CHANGED (&(_ELM_ACTIONSLIDER_EVENT_ACCESS_CHANGED))
-
 /**
  * No description
  */
