@@ -1,5 +1,5 @@
 /**
- * @defgroup Config Elementary Config
+ * @defgroup Elm_Config Elementary Config
  * @ingroup Elementary
  *
  * Elementary configuration is formed by a set options bounded to a
@@ -17,7 +17,7 @@
  * future sessions.
  *
  * @return @c EINA_TRUE, when successful. @c EINA_FALSE, otherwise.
- * @ingroup Config
+ * @ingroup Elm_Config
  *
  * This function will take effect -- thus, do I/O -- immediately. Use
  * it when you want to save all configuration changes at once. The
@@ -32,7 +32,7 @@ EAPI Eina_Bool elm_config_save(void);
  * profile.
  *
  * @return @c EINA_TRUE, when successful. @c EINA_FALSE, otherwise.
- * @ingroup Config
+ * @ingroup Elm_Config
  *
  * Useful when you want to force reloading of configuration values for
  * a profile. If one removes user custom configuration directories,
@@ -45,7 +45,7 @@ EAPI void      elm_config_reload(void);
  * Flush all config settings then apply those settings to all applications
  * using elementary on the current display.
  *
- * @ingroup Config
+ * @ingroup Elm_Config
  */
 EAPI void      elm_config_all_flush(void);
 
@@ -54,7 +54,7 @@ EAPI void      elm_config_all_flush(void);
  */
 
 /**
- * @defgroup Profile Elementary Profile
+ * @defgroup Elm_Profile Elementary Profile
  * @ingroup Elementary
  *
  * Profiles are pre-set options that affect the whole look-and-feel of
@@ -74,7 +74,7 @@ EAPI void      elm_config_all_flush(void);
  * applications.
  *
  * @return The profile's name
- * @ingroup Profile
+ * @ingroup Elm_Profile
  */
 EAPI const char *elm_config_profile_get(void);
 
@@ -87,7 +87,7 @@ EAPI const char *elm_config_profile_get(void);
  * @param is_user Whether to lookup for a user profile (@c EINA_TRUE)
  *                or a system one (@c EINA_FALSE)
  * @return The profile's directory path.
- * @ingroup Profile
+ * @ingroup Elm_Profile
  *
  * @note You must free it with elm_config_profile_dir_free().
  */
@@ -98,7 +98,7 @@ EAPI const char *elm_config_profile_dir_get(const char *profile, Eina_Bool is_us
  * elm_config_profile_dir_get().
  *
  * @param p_dir The profile's path
- * @ingroup Profile
+ * @ingroup Elm_Profile
  *
  */
 EAPI void        elm_config_profile_dir_free(const char *p_dir);
@@ -108,22 +108,49 @@ EAPI void        elm_config_profile_dir_free(const char *p_dir);
  *
  * @return The profiles list. List node data are the profile name
  *         strings.
- * @ingroup Profile
+ * @ingroup Elm_Profile
  *
  * @note One must free this list, after usage, with the function
  *       elm_config_profile_list_free().
  */
 EAPI Eina_List  *elm_config_profile_list_get(void);
 
+/**
+ * Get Elementary's list of available profiles including hidden ones.
+ *
+ * This gets a full list of profiles even with hidden names that should not
+ * be user-visible.
+ *
+ * @return The profiles list. List node data are the profile name
+ *         strings.
+ * @ingroup Elm_Profile
+ *
+ * @note One must free this list, after usage, with the function
+ *       elm_config_profile_list_free().
+ * @since 1.17
+ */
+EAPI Eina_List  *elm_config_profile_list_full_get(void);
+
 /**
  * Free Elementary's list of available profiles.
  *
  * @param l The profiles list, as returned by elm_config_profile_list_get().
- * @ingroup Profile
+ * @ingroup Elm_Profile
  *
  */
 EAPI void        elm_config_profile_list_free(Eina_List *l);
 
+/**
+ * Return if a profile of the given name exists
+ * 
+ * @return EINA_TRUE if the profile exists, or EINA_FALSE if not
+ * @param profile The profile's name
+ * @ingroup Elm_Profile
+ *
+ * @since 1.17
+ */
+EAPI Eina_Bool   elm_config_profile_exists(const char *profile);
+
 /**
  * Set Elementary's profile.
  *
@@ -132,17 +159,72 @@ EAPI void        elm_config_profile_list_free(Eina_List *l);
  * affected.
  *
  * @param profile The profile's name
- * @ingroup Profile
+ * @ingroup Elm_Profile
  *
  */
 EAPI void        elm_config_profile_set(const char *profile);
 
+/**
+ * Take the current config and write it out to the named profile
+ *
+ * This will take the current in-memory config and write it out to the named
+ * profile specified by @p profile. This will not change profile for the
+ * application or make other processes switch profile.
+ * 
+ * @param profile The profile's name
+ * @ingroup Elm_Profile
+ *
+ * @since 1.17
+ */
+EAPI void        elm_config_profile_save(const char *profile);
+
+/**
+ * Add a new profile of the given name to be derived from the current profile
+ *
+ * This creates a new profile of name @p profile that will be derived from
+ * the currently used profile using the modification commands encoded in the
+ * @p derive_options string.
+ *
+ * At this point it is not expected that anyone would generally use this API
+ * except if you are a destktop environment and so the user base of this API
+ * will be enlightenment itself.
+ *
+ * @param profile The new profile's name
+ * @param derive_options A string of derive options detailing how to modify
+ *
+ * @see elm_config_profile_derived_del
+ * @ingroup Elm_Profile
+ *
+ * @since 1.17
+ */
+EAPI void        elm_config_profile_derived_add(const char *profile, const char *derive_options);
+
+/**
+ * Deletes a profile that is derived from the current one
+ *
+ * This deletes a derived profile added by elm_config_profile_derived_add().
+ * This will delete the profile of the given name @p profile that is derived
+ * from the current profile.
+ *
+ * At this point it is not expected that anyone would generally use this API
+ * except if you are a destktop environment and so the user base of this API
+ * will be enlightenment itself.
+ *
+ * @param profile The profile's name that is to be deleted
+ *
+ * @see elm_config_profile_derived_add
+ * @ingroup Elm_Profile
+ *
+ * @since 1.17
+ */
+EAPI void        elm_config_profile_derived_del(const char *profile);
+
 /**
  * @}
  */
 
 /**
- * @defgroup Scrolling Elementary Scrolling
+ * @defgroup Elm_Scrolling Elementary Scrolling
  * @ingroup Elementary
  *
  * These are functions setting how scrollable views in Elementary
@@ -158,7 +240,7 @@ EAPI void        elm_config_profile_set(const char *profile);
  * @return the thumb scroll bouncing state
  *
  * This is the default behavior for touch screens, in general.
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI Eina_Bool    elm_config_scroll_bounce_enabled_get(void);
 
@@ -169,7 +251,7 @@ EAPI Eina_Bool    elm_config_scroll_bounce_enabled_get(void);
  * @param enabled the thumb scroll bouncing state
  *
  * @see elm_config_scroll_bounce_enabled_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_bounce_enabled_set(Eina_Bool enabled);
 
@@ -179,7 +261,7 @@ EAPI void         elm_config_scroll_bounce_enabled_set(Eina_Bool enabled);
  *
  * @return the thumb scroll bounce friction
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_bounce_friction_get(void);
 
@@ -190,7 +272,7 @@ EAPI double       elm_config_scroll_bounce_friction_get(void);
  * @param friction the thumb scroll bounce friction
  *
  * @see elm_config_scroll_bounce_friction_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_bounce_friction_set(double friction);
 
@@ -200,7 +282,7 @@ EAPI void         elm_config_scroll_bounce_friction_set(double friction);
  *
  * @return the page scroll friction
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_page_scroll_friction_get(void);
 
@@ -211,17 +293,37 @@ EAPI double       elm_config_scroll_page_scroll_friction_get(void);
  * @param friction the page scroll friction
  *
  * @see elm_config_scroll_page_scroll_friction_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_page_scroll_friction_set(double friction);
 
+/**
+ * Get enable status of context menu disabled.
+ *
+ * @see elm_config_context_menu_disabled_set()
+ * @ingroup Elm_Entry
+ * @since 1.17
+ */
+EAPI Eina_Bool elm_config_context_menu_disabled_get(void);
+
+/**
+ * Enable or disable the context menu in entries.
+ *
+ * @param disabled disable context menu if @c EINA_TRUE, enable otherwise
+ *
+ * @see elm_config_context_menu_disabled_get()
+ * @ingroup Elm_Entry
+ * @since 1.17
+ */
+EAPI void elm_config_context_menu_disabled_set(Eina_Bool disabled);
+
 /**
  * Get the amount of inertia a scroller will impose at region bring
  * animations.
  *
  * @return the bring in scroll friction
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_bring_in_scroll_friction_get(void);
 
@@ -232,7 +334,7 @@ EAPI double       elm_config_scroll_bring_in_scroll_friction_get(void);
  * @param friction the bring in scroll friction
  *
  * @see elm_config_scroll_bring_in_scroll_friction_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_bring_in_scroll_friction_set(double friction);
 
@@ -242,7 +344,7 @@ EAPI void         elm_config_scroll_bring_in_scroll_friction_set(double friction
  *
  * @return the zoom friction
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_zoom_friction_get(void);
 
@@ -253,7 +355,7 @@ EAPI double       elm_config_scroll_zoom_friction_get(void);
  * @param friction the zoom friction
  *
  * @see elm_config_scroll_zoom_friction_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_zoom_friction_set(double friction);
 
@@ -267,7 +369,7 @@ EAPI void         elm_config_scroll_zoom_friction_set(double friction);
  * @note All other functions namespaced with "thumbscroll" will only
  *       have effect if this mode is enabled.
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI Eina_Bool    elm_config_scroll_thumbscroll_enabled_get(void);
 
@@ -278,7 +380,7 @@ EAPI Eina_Bool    elm_config_scroll_thumbscroll_enabled_get(void);
  * @param enabled the thumb scroll state
  *
  * @see elm_config_scroll_thumbscroll_enabled_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_enabled_set(Eina_Bool enabled);
 
@@ -290,7 +392,7 @@ EAPI void         elm_config_scroll_thumbscroll_enabled_set(Eina_Bool enabled);
  *
  * One would use higher values for touch screens, in general, because
  * of their inherent imprecision.
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI unsigned int elm_config_scroll_thumbscroll_threshold_get(void);
 
@@ -301,7 +403,7 @@ EAPI unsigned int elm_config_scroll_thumbscroll_threshold_get(void);
  * @param threshold the thumb scroll threshold
  *
  * @see elm_config_thumbscroll_threshold_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_threshold_set(unsigned int threshold);
 
@@ -311,7 +413,7 @@ EAPI void         elm_config_scroll_thumbscroll_threshold_set(unsigned int thres
  *
  * @return the thumb scroll hold threshold
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI unsigned int elm_config_scroll_thumbscroll_hold_threshold_get(void);
 
@@ -322,7 +424,7 @@ EAPI unsigned int elm_config_scroll_thumbscroll_hold_threshold_get(void);
  * @param threshold the thumb scroll hold threshold
  *
  * @see elm_config_thumbscroll_hold_threshold_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_hold_threshold_set(unsigned int threshold);
 
@@ -333,7 +435,7 @@ EAPI void         elm_config_scroll_thumbscroll_hold_threshold_set(unsigned int
  *
  * @return the thumb scroll momentum threshold
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_thumbscroll_momentum_threshold_get(void);
 
@@ -345,7 +447,7 @@ EAPI double       elm_config_scroll_thumbscroll_momentum_threshold_get(void);
  * @param threshold the thumb scroll momentum threshold
  *
  * @see elm_config_thumbscroll_momentum_threshold_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_momentum_threshold_set(double threshold);
 
@@ -356,7 +458,7 @@ EAPI void         elm_config_scroll_thumbscroll_momentum_threshold_set(double th
  *
  * @return the thumb scroll maximum flick distance
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI unsigned int elm_config_scroll_thumbscroll_flick_distance_tolerance_get(void);
 
@@ -368,7 +470,7 @@ EAPI unsigned int elm_config_scroll_thumbscroll_flick_distance_tolerance_get(voi
  * @param distance the thumb scroll maximum flick distance
  *
  * @see elm_config_thumbscroll_flick_distance_tolerance_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_flick_distance_tolerance_set(unsigned int distance);
 
@@ -378,7 +480,7 @@ EAPI void         elm_config_scroll_thumbscroll_flick_distance_tolerance_set(uns
  *
  * @return the thumb scroll friction
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_thumbscroll_friction_get(void);
 
@@ -389,7 +491,7 @@ EAPI double       elm_config_scroll_thumbscroll_friction_get(void);
  * @param friction the thumb scroll friction
  *
  * @see elm_config_thumbscroll_friction_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_friction_set(double friction);
 
@@ -399,7 +501,7 @@ EAPI void         elm_config_scroll_thumbscroll_friction_set(double friction);
  *
  * @return the thumb scroll min friction
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_thumbscroll_min_friction_get(void);
 
@@ -410,7 +512,7 @@ EAPI double       elm_config_scroll_thumbscroll_min_friction_get(void);
  * @param friction the thumb scroll min friction
  *
  * @see elm_config_thumbscroll_min_friction_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_min_friction_set(double friction);
 
@@ -421,7 +523,7 @@ EAPI void         elm_config_scroll_thumbscroll_min_friction_set(double friction
  *
  * @return the thumb scroll friction
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_thumbscroll_friction_standard_get(void);
 
@@ -433,7 +535,7 @@ EAPI double       elm_config_scroll_thumbscroll_friction_standard_get(void);
  * @param standard the thumb scroll friction standard
  *
  * @see elm_config_thumbscroll_friction_standard_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_friction_standard_set(double standard);
 
@@ -444,7 +546,7 @@ EAPI void         elm_config_scroll_thumbscroll_friction_standard_set(double sta
  *
  * @return the thumb scroll border friction
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_thumbscroll_border_friction_get(void);
 
@@ -460,7 +562,7 @@ EAPI double       elm_config_scroll_thumbscroll_border_friction_get(void);
  * @see elm_config_thumbscroll_border_friction_get()
  * @note parameter value will get bound to 0.0 - 1.0 interval, always
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_border_friction_set(double friction);
 
@@ -470,7 +572,7 @@ EAPI void         elm_config_scroll_thumbscroll_border_friction_set(double frict
  *
  * @return the thumb scroll sensitivity friction
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_thumbscroll_sensitivity_friction_get(void);
 
@@ -485,10 +587,94 @@ EAPI double       elm_config_scroll_thumbscroll_sensitivity_friction_get(void);
  * @see elm_config_thumbscroll_sensitivity_friction_get()
  * @note parameter value will get bound to 0.1 - 1.0 interval, always
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_sensitivity_friction_set(double friction);
 
+/**
+ * Get the smooth start mode for scrolling with your finger
+ *
+ * @return smooth scroll flag
+ * 
+ * @see elm_config_scroll_thumbscroll_smooth_start_set()
+ *
+ * @since 1.16
+ * @ingroup Elm_Scrolling
+ */
+EAPI Eina_Bool    elm_config_scroll_thumbscroll_smooth_start_get(void);
+
+/**
+ * Set the smooth start mode for scrolling with your finger
+ *
+ * This enabled finger scrolling to scroll from the currunt point rather than
+ * jumping and playing catch-up to make start of scrolling look smoother once
+ * the finger or mouse goes past the threshold.
+ * 
+ * @param enable The enabled state of the smooth scroller
+ * 
+ * @see elm_config_scroll_thumbscroll_smooth_start_get()
+ *
+ * @since 1.16
+ * @ingroup Elm_Scrolling
+ */
+EAPI void         elm_config_scroll_thumbscroll_smooth_start_set(Eina_Bool enable);
+
+/**
+ * Get the amount of smoothing to apply to scrolling
+ *
+ * @return the amount of smoothing to apply from 0.0 to 1.0
+ *
+ * @see elm_config_scroll_thumbscroll_smooth_amount_set()
+ *
+ * @since 1.16
+ * @ingroup Elm_Scrolling
+ */
+EAPI double       elm_config_scroll_thumbscroll_smooth_amount_get(void);
+
+/**
+ * Set the amount of smoothing to apply to scrolling
+ *
+ * Scrolling with your finger can be smoothed out and the amount to smooth
+ * is determined by this parameter. 0.0 means to not smooth at all and
+ * 1.0 is to smoth as much as possible.
+ * 
+ * @param the amount to smooth from 0.0 to 1.0 with 0.0 being none
+ *
+ * @see elm_config_thumbscroll_acceleration_threshold_set()
+ * 
+ * @since 1.16
+ * @ingroup Elm_Scrolling
+ */
+EAPI void         elm_config_scroll_thumbscroll_smooth_amount_set(double amount);
+
+/**
+ * Get the time window to look back at for events for smoothing
+ *
+ * @return the time window in seconds (between 0.0 and 1.0)
+ *
+ * @see elm_config_scroll_thumbscroll_smooth_time_window_set()
+ *
+ * @since 1.16
+ * @ingroup Elm_Scrolling
+ */
+EAPI double       elm_config_scroll_thumbscroll_smooth_time_window_get(void);
+
+/**
+ * Set the time window to look back at for events for smoothing
+ *
+ * Scrolling with your finger can be smoothed out and the window of time
+ * to look at is determined by this config. The value is in seconds and
+ * is from 0.0 to 1.0
+ * 
+ * @param the time window in seconds (between 0.0 and 1.0)
+ *
+ * @see elm_config_scroll_thumbscroll_smooth_time_window_get()
+ * 
+ * @since 1.16
+ * @ingroup Elm_Scrolling
+ */
+EAPI void         elm_config_scroll_thumbscroll_smooth_time_window_set(double amount);
+
 /**
  * Get the minimum speed of mouse cursor movement which will accelerate
  * scrolling velocity after a mouse up event
@@ -496,7 +682,7 @@ EAPI void         elm_config_scroll_thumbscroll_sensitivity_friction_set(double
  *
  * @return the thumb scroll acceleration threshold
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_thumbscroll_acceleration_threshold_get(void);
 
@@ -508,7 +694,7 @@ EAPI double       elm_config_scroll_thumbscroll_acceleration_threshold_get(void)
  * @param threshold the thumb scroll acceleration threshold
  *
  * @see elm_config_thumbscroll_acceleration_threshold_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_acceleration_threshold_set(double threshold);
 
@@ -517,7 +703,7 @@ EAPI void         elm_config_scroll_thumbscroll_acceleration_threshold_set(doubl
  *
  * @return the thumb scroll acceleration time limit
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_thumbscroll_acceleration_time_limit_get(void);
 
@@ -527,7 +713,7 @@ EAPI double       elm_config_scroll_thumbscroll_acceleration_time_limit_get(void
  * @param time_limit the thumb scroll acceleration time limit
  *
  * @see elm_config_thumbscroll_acceleration_time_limit_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_acceleration_time_limit_set(double time_limit);
 
@@ -536,7 +722,7 @@ EAPI void         elm_config_scroll_thumbscroll_acceleration_time_limit_set(doub
  *
  * @return the thumb scroll acceleration weight
  *
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI double       elm_config_scroll_thumbscroll_acceleration_weight_get(void);
 
@@ -546,7 +732,7 @@ EAPI double       elm_config_scroll_thumbscroll_acceleration_weight_get(void);
  * @param weight the thumb scroll acceleration weight
  *
  * @see elm_config_thumbscroll_acceleration_weight_get()
- * @ingroup Scrolling
+ * @ingroup Elm_Scrolling
  */
 EAPI void         elm_config_scroll_thumbscroll_acceleration_weight_set(double weight);
 
@@ -554,7 +740,7 @@ EAPI void         elm_config_scroll_thumbscroll_acceleration_weight_set(double w
  * Focus Autoscroll Mode
  *
  * @since 1.10
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 typedef enum
 {
@@ -571,7 +757,7 @@ typedef enum
  * viewport.
  *
  * @see elm_config_focus_autoscroll_mode_set()
- * @ingroup Focus
+ * @ingroup Elm_Focus
  * @since 1.10
  */
 EAPI Elm_Focus_Autoscroll_Mode elm_config_focus_autoscroll_mode_get(void);
@@ -589,7 +775,7 @@ EAPI Elm_Focus_Autoscroll_Mode elm_config_focus_autoscroll_mode_get(void);
  * default historically.
  *
  * @see elm_config_focus_autoscroll_mode_get()
- * @ingroup Focus
+ * @ingroup Elm_Focus
  * @since 1.10
  */
 EAPI void         elm_config_focus_autoscroll_mode_set(Elm_Focus_Autoscroll_Mode mode);
@@ -616,7 +802,7 @@ typedef enum
  * @param mode Elm_Slider_Indicator_Visible_Mode.
  * viewport.
  *
- * @ingroup Slider
+ * @ingroup Elm_Slider
  * @since 1.13
  */
 EAPI void elm_config_slider_indicator_visible_mode_set(Elm_Slider_Indicator_Visible_Mode mode);
@@ -629,7 +815,7 @@ EAPI void elm_config_slider_indicator_visible_mode_set(Elm_Slider_Indicator_Visi
  * @c ELM_SLIDER_INDICATOR_VISIBLE_MODE_ALWAYS, ELM_SLIDER_INDICATOR_VISIBLE_MODE_ON_FOCUS,
  *    ELM_SLIDER_INDICATOR_VISIBLE_MODE_NONE if any of the above is set by user.
  *
- * @ingroup Slider
+ * @ingroup Elm_Slider
  * @since 1.13
  */
 EAPI Elm_Slider_Indicator_Visible_Mode elm_config_slider_indicator_visible_mode_get(void);
@@ -708,7 +894,7 @@ EAPI void        elm_config_tooltip_delay_set(double delay);
  * This gets the globally configured exclusive usage of engine cursors.
  *
  * @return 1 if only engine cursors should be used
- * @ingroup Cursors
+ * @ingroup Elm_Cursors
  */
 EAPI Eina_Bool   elm_config_cursor_engine_only_get(void);
 
@@ -720,7 +906,7 @@ EAPI Eina_Bool   elm_config_cursor_engine_only_get(void);
  *
  * @param engine_only If 1 only engine cursors will be enabled, if 0 will
  * look for them on theme before.
- * @ingroup Cursors
+ * @ingroup Elm_Cursors
  */
 EAPI void        elm_config_cursor_engine_only_set(Eina_Bool engine_only);
 
@@ -731,7 +917,7 @@ EAPI void        elm_config_cursor_engine_only_set(Eina_Bool engine_only);
  * objects.
  *
  * @return The scaling factor
- * @ingroup Scaling
+ * @ingroup Elm_Scaling
  */
 EAPI double elm_config_scale_get(void);
 
@@ -742,12 +928,12 @@ EAPI double elm_config_scale_get(void);
  * objects.
  *
  * @param scale The scaling factor to set
- * @ingroup Scaling
+ * @ingroup Elm_Scaling
  */
 EAPI void   elm_config_scale_set(double scale);
 
 /**
- * @defgroup Password_last_show Password show last
+ * @defgroup Elm_Password_last_show Password show last
  * @ingroup Elementary
  *
  * Show last feature of password mode enables user to view
@@ -768,7 +954,7 @@ EAPI void   elm_config_scale_set(double scale);
  * @return @c EINA_TRUE, if the "show last" setting is enabled,
  * @c EINA_FALSE  if it's disabled.
  *
- * @ingroup Password_last_show
+ * @ingroup Elm_Password_last_show
  */
 EAPI Eina_Bool elm_config_password_show_last_get(void);
 
@@ -779,7 +965,7 @@ EAPI Eina_Bool elm_config_password_show_last_get(void);
  *
  * @param password_show_last If @c EINA_TRUE, enables "show last" in password mode.
  * @see elm_config_password_show_last_timeout_set()
- * @ingroup Password_last_show
+ * @ingroup Elm_Password_last_show
  */
 EAPI void      elm_config_password_show_last_set(Eina_Bool password_show_last);
 
@@ -790,7 +976,7 @@ EAPI void      elm_config_password_show_last_set(Eina_Bool password_show_last);
  * mode will be visible.
  *
  * @return The timeout value of "show last" password mode.
- * @ingroup Password_last_show
+ * @ingroup Elm_Password_last_show
  */
 EAPI double    elm_config_password_show_last_timeout_get(void);
 
@@ -802,7 +988,7 @@ EAPI double    elm_config_password_show_last_timeout_get(void);
  *
  * @param password_show_last_timeout The timeout value.
  * @see elm_config_password_show_last_set()
- * @ingroup Password_last_show
+ * @ingroup Elm_Password_last_show
  */
 EAPI void      elm_config_password_show_last_timeout_set(double password_show_last_timeout);
 
@@ -811,7 +997,7 @@ EAPI void      elm_config_password_show_last_timeout_set(double password_show_la
  */
 
 /**
- * @defgroup Engine Elementary Engine
+ * @defgroup Elm_Engine Elementary Engine
  * @ingroup Elementary
  *
  * These are functions setting and querying which rendering engine
@@ -919,6 +1105,7 @@ EAPI const char *elm_config_accel_preference_get(void);
  * "gl", "opengl" - try use OpenGL.
  * "3d" - try and use a 3d acceleration unit.
  * "hw", "hardware", "accel" - try any acceleration unit (best possible)
+ * "none" - use no acceleration. try use software (since 1.16)
  *
  * Since 1.14, it is also possible to specify some GL properties for the GL
  * window surface. This allows applications to use GLView with depth, stencil
@@ -928,7 +1115,7 @@ EAPI const char *elm_config_accel_preference_get(void);
  * Accepted values for depth are for instance "depth", "depth16", "depth24".
  * Accepted values for stencil are "stencil", "stencil1", "stencil8".
  * For MSAA, only predefined strings are accepted: "msaa", "msaa_low",
- * "msaa_mid" and "msaa_high". The selected configuration is not garanteed
+ * "msaa_mid" and "msaa_high". The selected configuration is not guaranteed
  * and is only valid in case of GL acceleration. Only the base acceleration
  * string will be saved (e.g. "gl" or "hw").
  *
@@ -967,7 +1154,7 @@ typedef struct _Elm_Font_Overlay
  * Get Elementary's list of supported text classes.
  *
  * @return The text classes list, with @c Elm_Text_Class blobs as data.
- * @ingroup Fonts
+ * @ingroup Elm_Fonts
  *
  * Release the list with elm_text_classes_list_free().
  */
@@ -976,7 +1163,7 @@ EAPI Eina_List *elm_config_text_classes_list_get(void);
 /**
  * Free Elementary's list of supported text classes.
  *
- * @ingroup Fonts
+ * @ingroup Elm_Fonts
  *
  * @see elm_config_text_classes_list_get().
  */
@@ -989,7 +1176,7 @@ EAPI void elm_config_text_classes_list_free(Eina_List *list);
  * @return The font overlays list, with @c Elm_Font_Overlay blobs as
  * data.
  *
- * @ingroup Fonts
+ * @ingroup Elm_Fonts
  *
  * For each text class, one can set a <b>font overlay</b> for it,
  * overriding the default font properties for that class coming from
@@ -1008,7 +1195,7 @@ EAPI const Eina_List *elm_config_font_overlay_list_get(void);
  *
  * @note If the @p size is lower than zero, the value will be the amount of the size percentage. ex) -50: half of the current size, -100: current size, -10: 1/10 size.
  *
- * @ingroup Fonts
+ * @ingroup Elm_Fonts
  *
  * @p font has to be in the format returned by elm_font_fontconfig_name_get().
  * @see elm_config_font_overlay_list_get()
@@ -1079,7 +1266,7 @@ EAPI void             elm_config_selection_unfocused_clear_set(Eina_Bool enabled
  *
  * @param text_class Text class name
  *
- * @ingroup Fonts
+ * @ingroup Elm_Fonts
  *
  * This will bring back text elements belonging to text class
  * @p text_class back to their default font settings.
@@ -1090,7 +1277,7 @@ EAPI void             elm_config_font_overlay_unset(const char *text_class);
  * Apply the changes made with elm_config_font_overlay_set() and
  * elm_config_font_overlay_unset() on the current Elementary window.
  *
- * @ingroup Fonts
+ * @ingroup Elm_Fonts
  *
  * This applies all font overlays set to all objects in the UI.
  */
@@ -1102,7 +1289,7 @@ EAPI void             elm_config_font_overlay_apply(void);
  * EVAS_FONT_HINTING_AUTO < Automatic font hinting
  * EVAS_FONT_HINTING_BYTECODE < Bytecode font hinting
  *
- * @ingroup Fonts
+ * @ingroup Elm_Fonts
  *
  * This applies font hint changes to all windows of the current application.
  *
@@ -1117,7 +1304,7 @@ EAPI void elm_config_font_hint_type_set(int type);
  *
  * This gets the globally configured finger size, <b>in pixels</b>
  *
- * @ingroup Fingers
+ * @ingroup Elm_Fingers
  */
 EAPI Evas_Coord elm_config_finger_size_get(void);
 
@@ -1127,7 +1314,7 @@ EAPI Evas_Coord elm_config_finger_size_get(void);
  * This sets the globally configured finger size in pixels
  *
  * @param size The finger size
- * @ingroup Fingers
+ * @ingroup Elm_Fingers
  */
 EAPI void       elm_config_finger_size_set(Evas_Coord size);
 
@@ -1138,7 +1325,7 @@ EAPI void       elm_config_finger_size_set(Evas_Coord size);
  * ticks
  *
  * @return The cache flush interval time
- * @ingroup Caches
+ * @ingroup Elm_Caches
  *
  * @see elm_cache_all_flush()
  */
@@ -1154,7 +1341,7 @@ EAPI int       elm_config_cache_flush_interval_get(void);
  * @note The @p size must be greater than 0. if not, the cache flush will be
  *       ignored.
  *
- * @ingroup Caches
+ * @ingroup Elm_Caches
  *
  * @see elm_cache_all_flush()
  */
@@ -1172,7 +1359,7 @@ EAPI void      elm_config_cache_flush_interval_set(int size);
  * not rendering or doing anything graphically right now.
  *
  * @return The cache flush state
- * @ingroup Caches
+ * @ingroup Elm_Caches
  *
  * @see elm_cache_all_flush()
  */
@@ -1184,7 +1371,7 @@ EAPI Eina_Bool elm_config_cache_flush_enabled_get(void);
  * This sets the globally configured cache flush enabled state.
  *
  * @param enabled The cache flush enabled state
- * @ingroup Caches
+ * @ingroup Elm_Caches
  *
  * @see elm_cache_all_flush()
  */
@@ -1196,7 +1383,7 @@ EAPI void      elm_config_cache_flush_enabled_set(Eina_Bool enabled);
  * This gets the globally configured font cache size, in kilo bytes.
  *
  * @return The font cache size
- * @ingroup Caches
+ * @ingroup Elm_Caches
  */
 EAPI int       elm_config_cache_font_cache_size_get(void);
 
@@ -1206,7 +1393,7 @@ EAPI int       elm_config_cache_font_cache_size_get(void);
  * This sets the globally configured font cache size, in kilo bytes
  *
  * @param size The font cache size
- * @ingroup Caches
+ * @ingroup Elm_Caches
  */
 EAPI void      elm_config_cache_font_cache_size_set(int size);
 
@@ -1216,7 +1403,7 @@ EAPI void      elm_config_cache_font_cache_size_set(int size);
  * This gets the globally configured image cache size, in kilo bytes
  *
  * @return The image cache size
- * @ingroup Caches
+ * @ingroup Elm_Caches
  */
 EAPI int       elm_config_cache_image_cache_size_get(void);
 
@@ -1226,7 +1413,7 @@ EAPI int       elm_config_cache_image_cache_size_get(void);
  * This sets the globally configured image cache size, in kilo bytes
  *
  * @param size The image cache size
- * @ingroup Caches
+ * @ingroup Elm_Caches
  */
 EAPI void       elm_config_cache_image_cache_size_set(int size);
 
@@ -1237,7 +1424,7 @@ EAPI void       elm_config_cache_image_cache_size_set(int size);
  * of files.
  *
  * @return The edje file cache size
- * @ingroup Caches
+ * @ingroup Elm_Caches
  */
 EAPI int       elm_config_cache_edje_file_cache_size_get(void);
 
@@ -1248,7 +1435,7 @@ EAPI int       elm_config_cache_edje_file_cache_size_get(void);
  * of files.
  *
  * @param size The edje file cache size
- * @ingroup Caches
+ * @ingroup Elm_Caches
  */
 EAPI void       elm_config_cache_edje_file_cache_size_set(int size);
 
@@ -1259,7 +1446,7 @@ EAPI void       elm_config_cache_edje_file_cache_size_set(int size);
  * number of collections.
  *
  * @return The edje collections cache size
- * @ingroup Caches
+ * @ingroup Elm_Caches
  */
 EAPI int       elm_config_cache_edje_collection_cache_size_get(void);
 
@@ -1270,7 +1457,7 @@ EAPI int       elm_config_cache_edje_collection_cache_size_get(void);
  * number of collections.
  *
  * @param size The edje collections cache size
- * @ingroup Caches
+ * @ingroup Elm_Caches
  */
 EAPI void       elm_config_cache_edje_collection_cache_size_set(int size);
 
@@ -1337,7 +1524,7 @@ EAPI void       elm_config_accel_preference_override_set(Eina_Bool enabled);
  * otherwise.
  *
  * @see elm_config_focus_highlight_enabled_set()
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI Eina_Bool            elm_config_focus_highlight_enabled_get(void);
 
@@ -1352,7 +1539,7 @@ EAPI Eina_Bool            elm_config_focus_highlight_enabled_get(void);
  * this is called.
  *
  * @see elm_config_focus_highlight_enabled_get()
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI void                 elm_config_focus_highlight_enabled_set(Eina_Bool enable);
 
@@ -1366,7 +1553,7 @@ EAPI void                 elm_config_focus_highlight_enabled_set(Eina_Bool enabl
  * one object to the next
  *
  * @see elm_config_focus_highlight_animate_set()
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI Eina_Bool            elm_config_focus_highlight_animate_get(void);
 
@@ -1382,7 +1569,7 @@ EAPI Eina_Bool            elm_config_focus_highlight_animate_get(void);
  * this is called.
  *
  * @see elm_config_focus_highlight_animate_get()
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI void                 elm_config_focus_highlight_animate_set(Eina_Bool animate);
 
@@ -1397,7 +1584,7 @@ EAPI void                 elm_config_focus_highlight_animate_set(Eina_Bool anima
  *
  * @see elm_config_focus_highlight_clip_disabled_set()
  * @since 1.10
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI Eina_Bool elm_config_focus_highlight_clip_disabled_get(void);
 
@@ -1409,7 +1596,7 @@ EAPI Eina_Bool elm_config_focus_highlight_clip_disabled_get(void);
  *
  * @see elm_config_focus_highlight_clip_disabled_get()
  * @since 1.10
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI void elm_config_focus_highlight_clip_disabled_set(Eina_Bool disable);
 
@@ -1438,7 +1625,7 @@ typedef enum
  *
  * @see elm_config_focus_move_policy_set()
  * @since 1.10
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI Elm_Focus_Move_Policy elm_config_focus_move_policy_get(void);
 
@@ -1449,7 +1636,7 @@ EAPI Elm_Focus_Move_Policy elm_config_focus_move_policy_get(void);
  *
  * @see elm_config_focus_move_policy_get()
  * @since 1.10
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI void elm_config_focus_move_policy_set(Elm_Focus_Move_Policy policy);
 
@@ -1460,7 +1647,7 @@ EAPI void elm_config_focus_move_policy_set(Elm_Focus_Move_Policy policy);
  *
  * @see elm_config_item_select_on_focus_disabled_set
  * @since 1.10
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI Eina_Bool elm_config_item_select_on_focus_disabled_get(void);
 
@@ -1471,7 +1658,7 @@ EAPI Eina_Bool elm_config_item_select_on_focus_disabled_get(void);
  *
  * @see elm_config_item_select_on_focus_disabled_get
  * @since 1.10
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI void elm_config_item_select_on_focus_disabled_set(Eina_Bool disabled);
 
@@ -1482,7 +1669,7 @@ EAPI void elm_config_item_select_on_focus_disabled_set(Eina_Bool disabled);
  *
  * @see elm_config_first_item_focus_on_first_focusin_set
  * @since 1.11
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI Eina_Bool elm_config_first_item_focus_on_first_focusin_get(void);
 
@@ -1493,7 +1680,7 @@ EAPI Eina_Bool elm_config_first_item_focus_on_first_focusin_get(void);
  *
  * @see elm_config_first_item_focus_on_first_focusin_get
  * @since 1.11
- * @ingroup Focus
+ * @ingroup Elm_Focus
  */
 EAPI void elm_config_first_item_focus_on_first_focusin_set(Eina_Bool enabled);
 
