@@ -27,7 +27,7 @@ typedef Eo Elm_Ctxpopup_Item;
  *
  * @ingroup Elm_Ctxpopup_Item
  */
-EAPI Elm_Object_Item *elm_ctxpopup_item_prev_get(const Elm_Ctxpopup_Item *obj);
+EAPI Elm_Widget_Item *elm_ctxpopup_item_prev_get(const Elm_Ctxpopup_Item *obj);
 
 /**
  * @brief Get the item after $ it in a ctxpopup widget's internal list of
@@ -42,14 +42,7 @@ EAPI Elm_Object_Item *elm_ctxpopup_item_prev_get(const Elm_Ctxpopup_Item *obj);
  *
  * @ingroup Elm_Ctxpopup_Item
  */
-EAPI Elm_Object_Item *elm_ctxpopup_item_next_get(const Elm_Ctxpopup_Item *obj);
-
-/**
- * No description supplied.
- *
- * @param[in] func No description supplied.
- * @param[in] data No description supplied.
- */
+EAPI Elm_Widget_Item *elm_ctxpopup_item_next_get(const Elm_Ctxpopup_Item *obj);
 EAPI void elm_ctxpopup_item_init(Elm_Ctxpopup_Item *obj, Evas_Smart_Cb func, const void *data);
 
 #endif
