@@ -53,7 +53,7 @@ EAPI const Eo_Class *elm_datetime_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Datetime
  */
-EOAPI void  elm_obj_datetime_format_set(const char *fmt);
+EOAPI void elm_obj_datetime_format_set(const char *fmt);
 
 /**
  * @brief Get the datetime format.
@@ -62,7 +62,7 @@ EOAPI void  elm_obj_datetime_format_set(const char *fmt);
  *
  * @ingroup Elm_Datetime
  */
-EOAPI const char * elm_obj_datetime_format_get(void);
+EOAPI const char *elm_obj_datetime_format_get(void);
 
 /**
  * @brief Set the field limits of a field.
@@ -80,7 +80,7 @@ EOAPI const char * elm_obj_datetime_format_get(void);
  *
  * @ingroup Elm_Datetime
  */
-EOAPI void  elm_obj_datetime_field_limit_set(Elm_Datetime_Field_Type fieldtype, int min, int max);
+EOAPI void elm_obj_datetime_field_limit_set(Elm_Datetime_Field_Type fieldtype, int min, int max);
 
 /**
  * @brief Get the field limits of a field.
@@ -98,7 +98,7 @@ EOAPI void  elm_obj_datetime_field_limit_set(Elm_Datetime_Field_Type fieldtype,
  *
  * @ingroup Elm_Datetime
  */
-EOAPI void  elm_obj_datetime_field_limit_get(Elm_Datetime_Field_Type fieldtype, int *min, int *max);
+EOAPI void elm_obj_datetime_field_limit_get(Elm_Datetime_Field_Type fieldtype, int *min, int *max);
 
 /**
  * @brief Set the lower boundary of a field.
@@ -120,7 +120,7 @@ EOAPI void  elm_obj_datetime_field_limit_get(Elm_Datetime_Field_Type fieldtype,
  *
  * @ingroup Elm_Datetime
  */
-EOAPI Eina_Bool  elm_obj_datetime_value_min_set(const Elm_Datetime_Time *mintime);
+EOAPI Eina_Bool elm_obj_datetime_value_min_set(const Elm_Datetime_Time *mintime);
 
 /**
  * @brief Get the lower boundary of a field.
@@ -142,7 +142,7 @@ EOAPI Eina_Bool  elm_obj_datetime_value_min_set(const Elm_Datetime_Time *mintime
  *
  * @ingroup Elm_Datetime
  */
-EOAPI Eina_Bool  elm_obj_datetime_value_min_get(Elm_Datetime_Time *mintime);
+EOAPI Eina_Bool elm_obj_datetime_value_min_get(Elm_Datetime_Time *mintime);
 
 /**
  * @brief Set the current value of a Datetime object.
@@ -164,7 +164,7 @@ EOAPI Eina_Bool  elm_obj_datetime_value_min_get(Elm_Datetime_Time *mintime);
  *
  * @ingroup Elm_Datetime
  */
-EOAPI Eina_Bool  elm_obj_datetime_value_set(const Elm_Datetime_Time *newtime);
+EOAPI Eina_Bool elm_obj_datetime_value_set(const Elm_Datetime_Time *newtime);
 
 /**
  * @brief Get the current value of a Datetime object.
@@ -186,7 +186,7 @@ EOAPI Eina_Bool  elm_obj_datetime_value_set(const Elm_Datetime_Time *newtime);
  *
  * @ingroup Elm_Datetime
  */
-EOAPI Eina_Bool  elm_obj_datetime_value_get(Elm_Datetime_Time *currtime);
+EOAPI Eina_Bool elm_obj_datetime_value_get(Elm_Datetime_Time *currtime);
 
 /**
  * @brief Set a field to be visible or not.
@@ -204,7 +204,7 @@ EOAPI Eina_Bool  elm_obj_datetime_value_get(Elm_Datetime_Time *currtime);
  *
  * @ingroup Elm_Datetime
  */
-EOAPI void  elm_obj_datetime_field_visible_set(Elm_Datetime_Field_Type fieldtype, Eina_Bool visible);
+EOAPI void elm_obj_datetime_field_visible_set(Elm_Datetime_Field_Type fieldtype, Eina_Bool visible);
 
 /**
  * @brief Get whether a field can be visible/not.
@@ -215,7 +215,7 @@ EOAPI void  elm_obj_datetime_field_visible_set(Elm_Datetime_Field_Type fieldtype
  *
  * @ingroup Elm_Datetime
  */
-EOAPI Eina_Bool  elm_obj_datetime_field_visible_get(Elm_Datetime_Field_Type fieldtype);
+EOAPI Eina_Bool elm_obj_datetime_field_visible_get(Elm_Datetime_Field_Type fieldtype);
 
 /**
  * @brief Set the upper boundary of a field.
@@ -237,7 +237,7 @@ EOAPI Eina_Bool  elm_obj_datetime_field_visible_get(Elm_Datetime_Field_Type fiel
  *
  * @ingroup Elm_Datetime
  */
-EOAPI Eina_Bool  elm_obj_datetime_value_max_set(const Elm_Datetime_Time *maxtime);
+EOAPI Eina_Bool elm_obj_datetime_value_max_set(const Elm_Datetime_Time *maxtime);
 
 /**
  * @brief Get the upper boundary of a field.
@@ -259,25 +259,13 @@ EOAPI Eina_Bool  elm_obj_datetime_value_max_set(const Elm_Datetime_Time *maxtime
  *
  * @ingroup Elm_Datetime
  */
-EOAPI Eina_Bool  elm_obj_datetime_value_max_get(Elm_Datetime_Time *maxtime);
+EOAPI Eina_Bool elm_obj_datetime_value_max_get(Elm_Datetime_Time *maxtime);
 
 EOAPI extern const Eo_Event_Description _ELM_DATETIME_EVENT_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_DATETIME_EVENT_LANGUAGE_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_DATETIME_EVENT_ACCESS_CHANGED;
 
 /**
  * No description
  */
 #define ELM_DATETIME_EVENT_CHANGED (&(_ELM_DATETIME_EVENT_CHANGED))
 
-/**
- * No description
- */
-#define ELM_DATETIME_EVENT_LANGUAGE_CHANGED (&(_ELM_DATETIME_EVENT_LANGUAGE_CHANGED))
-
-/**
- * No description
- */
-#define ELM_DATETIME_EVENT_ACCESS_CHANGED (&(_ELM_DATETIME_EVENT_ACCESS_CHANGED))
-
 #endif
