@@ -39,7 +39,7 @@ EAPI const Eo_Class *elm_gengrid_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_align_set(double align_x, double align_y);
+EOAPI void elm_obj_gengrid_align_set(double align_x, double align_y);
 
 /**
  * @brief Get the items grid's alignment values within a given gengrid widget.
@@ -52,7 +52,7 @@ EOAPI void  elm_obj_gengrid_align_set(double align_x, double align_y);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_align_get(double *align_x, double *align_y);
+EOAPI void elm_obj_gengrid_align_get(double *align_x, double *align_y);
 
 /**
  * @brief Set how the items grid's filled within a given gengrid widget
@@ -66,7 +66,7 @@ EOAPI void  elm_obj_gengrid_align_get(double *align_x, double *align_y);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_filled_set(Eina_Bool fill);
+EOAPI void elm_obj_gengrid_filled_set(Eina_Bool fill);
 
 /**
  * @brief Get how the items grid's filled within a given gengrid widget
@@ -76,7 +76,7 @@ EOAPI void  elm_obj_gengrid_filled_set(Eina_Bool fill);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Eina_Bool  elm_obj_gengrid_filled_get(void);
+EOAPI Eina_Bool elm_obj_gengrid_filled_get(void);
 
 /**
  * @brief Control  a given gengrid widget's scrolling page size, relative to
@@ -87,7 +87,7 @@ EOAPI Eina_Bool  elm_obj_gengrid_filled_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_page_relative_set(double h_pagerel, double v_pagerel);
+EOAPI void elm_obj_gengrid_page_relative_set(double h_pagerel, double v_pagerel);
 
 /**
  * @brief Control  a given gengrid widget's scrolling page size, relative to
@@ -98,7 +98,7 @@ EOAPI void  elm_obj_gengrid_page_relative_set(double h_pagerel, double v_pagerel
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_page_relative_get(double *h_pagerel, double *v_pagerel);
+EOAPI void elm_obj_gengrid_page_relative_get(double *h_pagerel, double *v_pagerel);
 
 /**
  * @brief Enable or disable multi-selection in a given gengrid widget.
@@ -115,14 +115,14 @@ EOAPI void  elm_obj_gengrid_page_relative_get(double *h_pagerel, double *v_pager
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_multi_select_set(Eina_Bool multi);
+EOAPI void elm_obj_gengrid_multi_select_set(Eina_Bool multi);
 
 /** Get whether multi-selection is enabled or disabled for a given gengrid
  * widget.
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Eina_Bool  elm_obj_gengrid_multi_select_get(void);
+EOAPI Eina_Bool elm_obj_gengrid_multi_select_get(void);
 
 /**
  * @brief Set the size for the group items of a given gengrid widget.
@@ -137,7 +137,7 @@ EOAPI Eina_Bool  elm_obj_gengrid_multi_select_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_group_item_size_set(Evas_Coord w, Evas_Coord h);
+EOAPI void elm_obj_gengrid_group_item_size_set(Evas_Coord w, Evas_Coord h);
 
 /**
  * @brief Get the size set for the group items of a given gengrid widget.
@@ -150,7 +150,7 @@ EOAPI void  elm_obj_gengrid_group_item_size_set(Evas_Coord w, Evas_Coord h);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_group_item_size_get(Evas_Coord *w, Evas_Coord *h);
+EOAPI void elm_obj_gengrid_group_item_size_get(Evas_Coord *w, Evas_Coord *h);
 
 /**
  * @brief Set the gengrid select mode.
@@ -168,7 +168,7 @@ EOAPI void  elm_obj_gengrid_group_item_size_get(Evas_Coord *w, Evas_Coord *h);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_select_mode_set(Elm_Object_Select_Mode mode);
+EOAPI void elm_obj_gengrid_select_mode_set(Elm_Object_Select_Mode mode);
 
 /**
  * @brief Get the gengrid select mode.
@@ -177,7 +177,7 @@ EOAPI void  elm_obj_gengrid_select_mode_set(Elm_Object_Select_Mode mode);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Object_Select_Mode  elm_obj_gengrid_select_mode_get(void);
+EOAPI Elm_Object_Select_Mode elm_obj_gengrid_select_mode_get(void);
 
 /**
  * @brief Set whether a given gengrid widget is or not able have items
@@ -196,7 +196,7 @@ EOAPI Elm_Object_Select_Mode  elm_obj_gengrid_select_mode_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_reorder_mode_set(Eina_Bool reorder_mode);
+EOAPI void elm_obj_gengrid_reorder_mode_set(Eina_Bool reorder_mode);
 
 /**
  * @brief Get whether a given gengrid widget is or not able have items
@@ -206,7 +206,7 @@ EOAPI void  elm_obj_gengrid_reorder_mode_set(Eina_Bool reorder_mode);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Eina_Bool  elm_obj_gengrid_reorder_mode_get(void);
+EOAPI Eina_Bool elm_obj_gengrid_reorder_mode_get(void);
 
 /**
  * @brief Control whether the gengrid items' should be highlighted when item
@@ -216,14 +216,14 @@ EOAPI Eina_Bool  elm_obj_gengrid_reorder_mode_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_highlight_mode_set(Eina_Bool highlight);
+EOAPI void elm_obj_gengrid_highlight_mode_set(Eina_Bool highlight);
 
 /** Control whether the gengrid items' should be highlighted when item
  * selected.
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Eina_Bool  elm_obj_gengrid_highlight_mode_get(void);
+EOAPI Eina_Bool elm_obj_gengrid_highlight_mode_get(void);
 
 /**
  * @brief Set the Gengrid reorder type
@@ -234,7 +234,7 @@ EOAPI Eina_Bool  elm_obj_gengrid_highlight_mode_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_reorder_type_set(Elm_Gengrid_Reorder_Type type);
+EOAPI void elm_obj_gengrid_reorder_type_set(Elm_Gengrid_Reorder_Type type);
 
 /**
  * @brief Set the size for the items of a given gengrid widget.
@@ -249,7 +249,7 @@ EOAPI void  elm_obj_gengrid_reorder_type_set(Elm_Gengrid_Reorder_Type type);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_item_size_set(Evas_Coord w, Evas_Coord h);
+EOAPI void elm_obj_gengrid_item_size_set(Evas_Coord w, Evas_Coord h);
 
 /**
  * @brief Get the size set for the items of a given gengrid widget.
@@ -262,7 +262,7 @@ EOAPI void  elm_obj_gengrid_item_size_set(Evas_Coord w, Evas_Coord h);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_item_size_get(Evas_Coord *w, Evas_Coord *h);
+EOAPI void elm_obj_gengrid_item_size_get(Evas_Coord *w, Evas_Coord *h);
 
 /**
  * @brief Set the gengrid multi select mode.
@@ -279,7 +279,7 @@ EOAPI void  elm_obj_gengrid_item_size_get(Evas_Coord *w, Evas_Coord *h);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_multi_select_mode_set(Elm_Object_Multi_Select_Mode mode);
+EOAPI void elm_obj_gengrid_multi_select_mode_set(Elm_Object_Multi_Select_Mode mode);
 
 /**
  * @brief Get the gengrid multi select mode.
@@ -292,7 +292,7 @@ EOAPI void  elm_obj_gengrid_multi_select_mode_set(Elm_Object_Multi_Select_Mode m
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Object_Multi_Select_Mode  elm_obj_gengrid_multi_select_mode_get(void);
+EOAPI Elm_Object_Multi_Select_Mode elm_obj_gengrid_multi_select_mode_get(void);
 
 /**
  * @brief Set the direction in which a given gengrid widget will expand while
@@ -312,7 +312,7 @@ EOAPI Elm_Object_Multi_Select_Mode  elm_obj_gengrid_multi_select_mode_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_horizontal_set(Eina_Bool horizontal);
+EOAPI void elm_obj_gengrid_horizontal_set(Eina_Bool horizontal);
 
 /**
  * @brief Get for what direction a given gengrid widget will expand while
@@ -323,7 +323,7 @@ EOAPI void  elm_obj_gengrid_horizontal_set(Eina_Bool horizontal);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Eina_Bool  elm_obj_gengrid_horizontal_get(void);
+EOAPI Eina_Bool elm_obj_gengrid_horizontal_get(void);
 
 /**
  * @brief Set a given gengrid widget's scrolling page size.
@@ -333,7 +333,7 @@ EOAPI Eina_Bool  elm_obj_gengrid_horizontal_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_page_size_set(Evas_Coord h_pagesize, Evas_Coord v_pagesize);
+EOAPI void elm_obj_gengrid_page_size_set(Evas_Coord h_pagesize, Evas_Coord v_pagesize);
 
 /**
  * @brief Get the selected item in a given gengrid widget.
@@ -348,7 +348,7 @@ EOAPI void  elm_obj_gengrid_page_size_set(Evas_Coord h_pagesize, Evas_Coord v_pa
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_selected_item_get(void);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_selected_item_get(void);
 
 /**
  * @brief Get a list of realized items in gengrid.
@@ -362,7 +362,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_selected_item_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Eina_List * elm_obj_gengrid_realized_items_get(void);
+EOAPI Eina_List *elm_obj_gengrid_realized_items_get(void);
 
 /**
  * @brief Get the first item in a given gengrid widget.
@@ -374,7 +374,7 @@ EOAPI Eina_List * elm_obj_gengrid_realized_items_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_first_item_get(void);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_first_item_get(void);
 
 /**
  * @brief Get a list of selected items in a given gengrid.
@@ -389,7 +389,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_first_item_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI const Eina_List * elm_obj_gengrid_selected_items_get(void);
+EOAPI const Eina_List *elm_obj_gengrid_selected_items_get(void);
 
 /**
  * @brief Get the last item in a given gengrid widget.
@@ -401,7 +401,7 @@ EOAPI const Eina_List * elm_obj_gengrid_selected_items_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_last_item_get(void);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_last_item_get(void);
 
 /**
  * @brief Enable or disable mouse wheel to be used to scroll the gengrid.
@@ -415,7 +415,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_last_item_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_wheel_disabled_set(Eina_Bool disabled);
+EOAPI void elm_obj_gengrid_wheel_disabled_set(Eina_Bool disabled);
 
 /**
  * @brief Get a value whether mouse wheel is enabled or not.
@@ -426,7 +426,7 @@ EOAPI void  elm_obj_gengrid_wheel_disabled_set(Eina_Bool disabled);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Eina_Bool  elm_obj_gengrid_wheel_disabled_get(void);
+EOAPI Eina_Bool elm_obj_gengrid_wheel_disabled_get(void);
 
 /**
  * @brief Insert an item before another in a gengrid widget.
@@ -442,7 +442,7 @@ EOAPI Eina_Bool  elm_obj_gengrid_wheel_disabled_get(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_item_insert_before(const Elm_Gengrid_Item_Class *itc, const void *data, Elm_Widget_Item *relative, Evas_Smart_Cb func, const void *func_data);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_item_insert_before(const Elm_Gengrid_Item_Class *itc, const void *data, Elm_Widget_Item *relative, Evas_Smart_Cb func, const void *func_data);
 
 /**
  * @brief Update the contents of all realized items.
@@ -455,7 +455,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_item_insert_before(const Elm_Gengrid_Ite
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_realized_items_update(void);
+EOAPI void elm_obj_gengrid_realized_items_update(void);
 
 /**
  * @brief Insert an item after another in a gengrid widget.
@@ -471,7 +471,7 @@ EOAPI void  elm_obj_gengrid_realized_items_update(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_item_insert_after(const Elm_Gengrid_Item_Class *itc, const void *data, Elm_Widget_Item *relative, Evas_Smart_Cb func, const void *func_data);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_item_insert_after(const Elm_Gengrid_Item_Class *itc, const void *data, Elm_Widget_Item *relative, Evas_Smart_Cb func, const void *func_data);
 
 /**
  * @brief Return how many items are currently in a list
@@ -480,7 +480,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_item_insert_after(const Elm_Gengrid_Item
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI unsigned int  elm_obj_gengrid_items_count(void);
+EOAPI unsigned int elm_obj_gengrid_items_count(void);
 
 /**
  * @brief Get the item that is at the x, y canvas coords.
@@ -506,7 +506,7 @@ EOAPI unsigned int  elm_obj_gengrid_items_count(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_at_xy_item_get(Evas_Coord x, Evas_Coord y, int *xposret, int *yposret);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_at_xy_item_get(Evas_Coord x, Evas_Coord y, int *xposret, int *yposret);
 
 /**
  * @brief Append a new item in a given gengrid widget.
@@ -521,7 +521,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_at_xy_item_get(Evas_Coord x, Evas_Coord
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_item_append(const Elm_Gengrid_Item_Class *itc, const void *data, Evas_Smart_Cb func, const void *func_data);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_item_append(const Elm_Gengrid_Item_Class *itc, const void *data, Evas_Smart_Cb func, const void *func_data);
 
 /**
  * @brief Prepend a new item in a given gengrid widget.
@@ -536,7 +536,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_item_append(const Elm_Gengrid_Item_Class
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_item_prepend(const Elm_Gengrid_Item_Class *itc, const void *data, Evas_Smart_Cb func, const void *func_data);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_item_prepend(const Elm_Gengrid_Item_Class *itc, const void *data, Evas_Smart_Cb func, const void *func_data);
 
 /**
  * @brief Remove all items from a given gengrid widget.
@@ -547,7 +547,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_item_prepend(const Elm_Gengrid_Item_Clas
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_clear(void);
+EOAPI void elm_obj_gengrid_clear(void);
 
 /**
  * @brief Insert an item in a gengrid widget using a user-defined sort
@@ -567,7 +567,7 @@ EOAPI void  elm_obj_gengrid_clear(void);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_item_sorted_insert(const Elm_Gengrid_Item_Class *itc, const void *data, Eina_Compare_Cb comp, Evas_Smart_Cb func, const void *func_data);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_item_sorted_insert(const Elm_Gengrid_Item_Class *itc, const void *data, Eina_Compare_Cb comp, Evas_Smart_Cb func, const void *func_data);
 
 /**
  * @brief Get gengrid item by given string.
@@ -591,7 +591,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_item_sorted_insert(const Elm_Gengrid_Ite
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_search_by_text_item_get(Elm_Widget_Item *item_to_search_from, const char *part_name, const char *pattern, Elm_Glob_Match_Flags flags);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_search_by_text_item_get(Elm_Widget_Item *item_to_search_from, const char *part_name, const char *pattern, Elm_Glob_Match_Flags flags);
 
 /**
  * @brief Starts the reorder mode of Gengrid
@@ -602,7 +602,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_search_by_text_item_get(Elm_Widget_Item
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_reorder_mode_start(Ecore_Pos_Map tween_mode);
+EOAPI void elm_obj_gengrid_reorder_mode_start(Ecore_Pos_Map tween_mode);
 
 /** Stops the reorder mode of Gengrid
  *
@@ -610,10 +610,8 @@ EOAPI void  elm_obj_gengrid_reorder_mode_start(Ecore_Pos_Map tween_mode);
  *
  * @ingroup Elm_Gengrid
  */
-EOAPI void  elm_obj_gengrid_reorder_mode_stop(void);
+EOAPI void elm_obj_gengrid_reorder_mode_stop(void);
 
-EOAPI extern const Eo_Event_Description _ELM_GENGRID_EVENT_LANGUAGE_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_GENGRID_EVENT_ACCESS_CHANGED;
 EOAPI extern const Eo_Event_Description _ELM_GENGRID_EVENT_REALIZED;
 EOAPI extern const Eo_Event_Description _ELM_GENGRID_EVENT_UNREALIZED;
 EOAPI extern const Eo_Event_Description _ELM_GENGRID_EVENT_INDEX_UPDATE;
@@ -631,16 +629,6 @@ EOAPI extern const Eo_Event_Description _ELM_GENGRID_EVENT_HIGHLIGHTED;
 EOAPI extern const Eo_Event_Description _ELM_GENGRID_EVENT_UNHIGHLIGHTED;
 EOAPI extern const Eo_Event_Description _ELM_GENGRID_EVENT_RELEASED;
 
-/**
- * No description
- */
-#define ELM_GENGRID_EVENT_LANGUAGE_CHANGED (&(_ELM_GENGRID_EVENT_LANGUAGE_CHANGED))
-
-/**
- * No description
- */
-#define ELM_GENGRID_EVENT_ACCESS_CHANGED (&(_ELM_GENGRID_EVENT_ACCESS_CHANGED))
-
 /**
  * No description
  */
