@@ -51,7 +51,9 @@ typedef enum
                                                   */
   ELM_GENLIST_ITEM_SCROLLTO_TOP = 2 /* 1 << 1 */, /** To the top of viewport.
                                                    */
-  ELM_GENLIST_ITEM_SCROLLTO_MIDDLE = 4 /* 1 << 2 */ /** To the middle of
+  ELM_GENLIST_ITEM_SCROLLTO_MIDDLE = 4 /* 1 << 2 */, /** To the middle of
+                                                      * viewport. */
+  ELM_GENLIST_ITEM_SCROLLTO_BOTTOM = 8 /* 1 << 3 */ /** To the bottom of
                                                      * viewport. */
 } Elm_Genlist_Item_Scrollto_Type;
 
@@ -67,11 +69,14 @@ EAPI const Eo_Class *elm_genlist_item_class_get(void) EINA_CONST;
  *
  * This returns the item placed before the @c item, on the container genlist.
  *
+ * If filter is set on genlist, this returns the filtered item placed before
+ * @c item in the list.
+ *
  * @return The item before @c item, or @c null if there's none (and on errors).
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_item_prev_get(void);
+EOAPI Elm_Widget_Item *elm_obj_genlist_item_prev_get(void);
 
 /**
  * @brief Get the next item in a genlist widget's internal lis of items, given
@@ -79,11 +84,14 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_item_prev_get(void);
  *
  * This returns the item placed after the @c item, on the container genlist.
  *
+ * If filter is set on genlist, this returns the filtered item placed after
+ * @c item in the list.
+ *
  * @return The item after @c item, or @c null if there's none (and on errors).
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_item_next_get(void);
+EOAPI Elm_Widget_Item *elm_obj_genlist_item_next_get(void);
 
 /**
  * @brief Get the parent item of the given item
@@ -95,7 +103,7 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_item_next_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_item_parent_get(void);
+EOAPI Elm_Widget_Item *elm_obj_genlist_item_parent_get(void);
 
 /**
  * @brief et the list of subitems of a given item
@@ -109,7 +117,7 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_item_parent_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI const Eina_List * elm_obj_genlist_item_subitems_get(void);
+EOAPI const Eina_List *elm_obj_genlist_item_subitems_get(void);
 
 /**
  * @brief Set whether a given genlist item is selected or not
@@ -123,7 +131,7 @@ EOAPI const Eina_List * elm_obj_genlist_item_subitems_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_selected_set(Eina_Bool selected);
+EOAPI void elm_obj_genlist_item_selected_set(Eina_Bool selected);
 
 /**
  * @brief Get whether a given genlist item is selected or not.
@@ -132,7 +140,7 @@ EOAPI void  elm_obj_genlist_item_selected_set(Eina_Bool selected);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI Eina_Bool  elm_obj_genlist_item_selected_get(void);
+EOAPI Eina_Bool elm_obj_genlist_item_selected_get(void);
 
 /**
  * @brief Sets the expanded state of an item.
@@ -153,7 +161,7 @@ EOAPI Eina_Bool  elm_obj_genlist_item_selected_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_expanded_set(Eina_Bool expanded);
+EOAPI void elm_obj_genlist_item_expanded_set(Eina_Bool expanded);
 
 /**
  * @brief Get the expanded state of an item
@@ -164,7 +172,7 @@ EOAPI void  elm_obj_genlist_item_expanded_set(Eina_Bool expanded);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI Eina_Bool  elm_obj_genlist_item_expanded_get(void);
+EOAPI Eina_Bool elm_obj_genlist_item_expanded_get(void);
 
 /**
  * @brief Get the depth of expanded item.
@@ -173,7 +181,7 @@ EOAPI Eina_Bool  elm_obj_genlist_item_expanded_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI int  elm_obj_genlist_item_expanded_depth_get(void);
+EOAPI int elm_obj_genlist_item_expanded_depth_get(void);
 
 /**
  * @brief Get the Genlist Item class for the given Genlist Item.
@@ -185,7 +193,7 @@ EOAPI int  elm_obj_genlist_item_expanded_depth_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI const Elm_Genlist_Item_Class * elm_obj_genlist_item_class_get(void);
+EOAPI const Elm_Genlist_Item_Class *elm_obj_genlist_item_class_get(void);
 
 /**
  * @brief Get the index of the item. It is only valid once displayed.
@@ -196,7 +204,7 @@ EOAPI const Elm_Genlist_Item_Class * elm_obj_genlist_item_class_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI int  elm_obj_genlist_item_index_get(void);
+EOAPI int elm_obj_genlist_item_index_get(void);
 
 /**
  * @brief Get the item's decorate mode.
@@ -207,7 +215,7 @@ EOAPI int  elm_obj_genlist_item_index_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI const char * elm_obj_genlist_item_decorate_mode_get(void);
+EOAPI const char *elm_obj_genlist_item_decorate_mode_get(void);
 
 /**
  * @brief Set the flip state of a given genlist item.
@@ -220,7 +228,7 @@ EOAPI const char * elm_obj_genlist_item_decorate_mode_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_flip_set(Eina_Bool flip);
+EOAPI void elm_obj_genlist_item_flip_set(Eina_Bool flip);
 
 /**
  * @brief Get the flip state of a given genlist item.
@@ -232,7 +240,7 @@ EOAPI void  elm_obj_genlist_item_flip_set(Eina_Bool flip);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI Eina_Bool  elm_obj_genlist_item_flip_get(void);
+EOAPI Eina_Bool elm_obj_genlist_item_flip_get(void);
 
 /**
  * @brief Set the genlist item's select mode.
@@ -259,7 +267,7 @@ EOAPI Eina_Bool  elm_obj_genlist_item_flip_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_select_mode_set(Elm_Object_Select_Mode mode);
+EOAPI void elm_obj_genlist_item_select_mode_set(Elm_Object_Select_Mode mode);
 
 /**
  * @brief Get the genlist item's select mode.
@@ -270,7 +278,7 @@ EOAPI void  elm_obj_genlist_item_select_mode_set(Elm_Object_Select_Mode mode);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI Elm_Object_Select_Mode  elm_obj_genlist_item_select_mode_get(void);
+EOAPI Elm_Object_Select_Mode elm_obj_genlist_item_select_mode_get(void);
 
 /**
  * @brief Get the Item's type.
@@ -282,7 +290,7 @@ EOAPI Elm_Object_Select_Mode  elm_obj_genlist_item_select_mode_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI Elm_Genlist_Item_Type  elm_obj_genlist_item_type_get(void);
+EOAPI Elm_Genlist_Item_Type elm_obj_genlist_item_type_get(void);
 
 /**
  * @brief Get the number of subitems of a given item.
@@ -295,7 +303,7 @@ EOAPI Elm_Genlist_Item_Type  elm_obj_genlist_item_type_get(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI unsigned int  elm_obj_genlist_item_subitems_count(void);
+EOAPI unsigned int elm_obj_genlist_item_subitems_count(void);
 
 /**
  * @brief Remove all sub-items (children) of the given item.
@@ -305,19 +313,19 @@ EOAPI unsigned int  elm_obj_genlist_item_subitems_count(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_subitems_clear(void);
+EOAPI void elm_obj_genlist_item_subitems_clear(void);
 
 /** Promote an item to the top of the list.
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_promote(void);
+EOAPI void elm_obj_genlist_item_promote(void);
 
 /** Demote an item to the end of the list.
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_demote(void);
+EOAPI void elm_obj_genlist_item_demote(void);
 
 /**
  * @brief Show the portion of a genlist's internal list containing a given
@@ -331,7 +339,7 @@ EOAPI void  elm_obj_genlist_item_demote(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_show(Elm_Genlist_Item_Scrollto_Type type);
+EOAPI void elm_obj_genlist_item_show(Elm_Genlist_Item_Scrollto_Type type);
 
 /**
  * @brief Animatedly bring in, to the visible area of a genlist, a given item
@@ -346,7 +354,7 @@ EOAPI void  elm_obj_genlist_item_show(Elm_Genlist_Item_Scrollto_Type type);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_bring_in(Elm_Genlist_Item_Scrollto_Type type);
+EOAPI void elm_obj_genlist_item_bring_in(Elm_Genlist_Item_Scrollto_Type type);
 
 /**
  * @brief Unset all contents fetched by the item class.
@@ -359,7 +367,7 @@ EOAPI void  elm_obj_genlist_item_bring_in(Elm_Genlist_Item_Scrollto_Type type);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_all_contents_unset(Eina_List **l);
+EOAPI void elm_obj_genlist_item_all_contents_unset(Eina_List **l);
 
 /**
  * @brief Update all the contents of an item.
@@ -379,7 +387,7 @@ EOAPI void  elm_obj_genlist_item_all_contents_unset(Eina_List **l);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_update(void);
+EOAPI void elm_obj_genlist_item_update(void);
 
 /**
  * @brief Update the part of an item.
@@ -396,7 +404,7 @@ EOAPI void  elm_obj_genlist_item_update(void);
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_fields_update(const char *parts, Elm_Genlist_Item_Field_Type itf);
+EOAPI void elm_obj_genlist_item_fields_update(const char *parts, Elm_Genlist_Item_Field_Type itf);
 
 /**
  * @brief Update the item class of an item.
@@ -409,7 +417,7 @@ EOAPI void  elm_obj_genlist_item_fields_update(const char *parts, Elm_Genlist_It
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_class_update(const Elm_Genlist_Item_Class *itc);
+EOAPI void elm_obj_genlist_item_class_update(const Elm_Genlist_Item_Class *itc);
 
 /**
  * @brief Activate a genlist mode on an item.
@@ -444,7 +452,7 @@ EOAPI void  elm_obj_genlist_item_class_update(const Elm_Genlist_Item_Class *itc)
  *
  * @ingroup Elm_Genlist_Item
  */
-EOAPI void  elm_obj_genlist_item_decorate_mode_set(const char *decorate_it_type, Eina_Bool decorate_it_set);
+EOAPI void elm_obj_genlist_item_decorate_mode_set(const char *decorate_it_type, Eina_Bool decorate_it_set);
 
 
 #endif
