@@ -31,7 +31,7 @@ EAPI const Eo_Class *elm_layout_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_edje_object_can_access_set(Eina_Bool can_access);
+EOAPI Eina_Bool elm_obj_layout_edje_object_can_access_set(Eina_Bool can_access);
 
 /**
  * @brief Get accessibility state of texblock(text) parts in the layout object
@@ -43,7 +43,7 @@ EOAPI Eina_Bool  elm_obj_layout_edje_object_can_access_set(Eina_Bool can_access)
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_edje_object_can_access_get(void);
+EOAPI Eina_Bool elm_obj_layout_edje_object_can_access_get(void);
 
 /**
  * @brief Set the edje group from the elementary theme that will be used as
@@ -58,11 +58,11 @@ EOAPI Eina_Bool  elm_obj_layout_edje_object_can_access_get(void);
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_theme_set(const char *klass, const char *group, const char *style);
+EOAPI Eina_Bool elm_obj_layout_theme_set(const char *klass, const char *group, const char *style);
 
-EOAPI const Elm_Layout_Part_Alias_Description * elm_obj_layout_text_aliases_get(void);
+EOAPI const Elm_Layout_Part_Alias_Description *elm_obj_layout_text_aliases_get(void);
 
-EOAPI const Elm_Layout_Part_Alias_Description * elm_obj_layout_content_aliases_get(void);
+EOAPI const Elm_Layout_Part_Alias_Description *elm_obj_layout_content_aliases_get(void);
 
 /**
  * @brief Get the edje layout
@@ -82,7 +82,28 @@ EOAPI const Elm_Layout_Part_Alias_Description * elm_obj_layout_content_aliases_g
  *
  * @ingroup Elm_Layout
  */
-EOAPI Evas_Object * elm_obj_layout_edje_get(void);
+EOAPI Evas_Object *elm_obj_layout_edje_get(void);
+
+/**
+ * @brief Set the text of the given part.
+ *
+ * @param[in] part The TEXT part where to set the text.
+ * @param[in] text The text to set.
+ *
+ * @ingroup Elm_Layout
+ */
+EOAPI Eina_Bool elm_obj_layout_text_set(const char * part, const char *text);
+
+/**
+ * @brief Get the text set in the given part.
+ *
+ * @param[in] part The TEXT part where to set the text.
+ *
+ * @return The text to set.
+ *
+ * @ingroup Elm_Layout
+ */
+EOAPI const char *elm_obj_layout_text_get(const char * part);
 
 /**
  * @brief Remove all children of the given part box.
@@ -96,7 +117,7 @@ EOAPI Evas_Object * elm_obj_layout_edje_get(void);
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_box_remove_all(const char *part, Eina_Bool clear);
+EOAPI Eina_Bool elm_obj_layout_box_remove_all(const char *part, Eina_Bool clear);
 
 /**
  * @brief Sets if the cursor set should be searched on the theme or should use
@@ -114,7 +135,7 @@ EOAPI Eina_Bool  elm_obj_layout_box_remove_all(const char *part, Eina_Bool clear
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_part_cursor_engine_only_set(const char *part_name, Eina_Bool engine_only);
+EOAPI Eina_Bool elm_obj_layout_part_cursor_engine_only_set(const char *part_name, Eina_Bool engine_only);
 
 /**
  * @brief Get a specific cursor engine_only for an edje part.
@@ -125,7 +146,7 @@ EOAPI Eina_Bool  elm_obj_layout_part_cursor_engine_only_set(const char *part_nam
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_part_cursor_engine_only_get(const char *part_name);
+EOAPI Eina_Bool elm_obj_layout_part_cursor_engine_only_get(const char *part_name);
 
 /**
  * @brief Unpack (remove) a child of the given part table.
@@ -140,7 +161,7 @@ EOAPI Eina_Bool  elm_obj_layout_part_cursor_engine_only_get(const char *part_nam
  *
  * @ingroup Elm_Layout
  */
-EOAPI Evas_Object * elm_obj_layout_table_unpack(const char *part, Evas_Object *child);
+EOAPI Evas_Object *elm_obj_layout_table_unpack(const char *part, Evas_Object *child);
 
 /**
  * @brief Freezes the Elementary layout object.
@@ -154,9 +175,9 @@ EOAPI Evas_Object * elm_obj_layout_table_unpack(const char *part, Evas_Object *c
  *
  * @ingroup Elm_Layout
  */
-EOAPI int  elm_obj_layout_freeze(void);
+EOAPI int elm_obj_layout_freeze(void);
 
-EOAPI Eina_Bool  elm_obj_layout_theme_enable(void);
+EOAPI Eina_Bool elm_obj_layout_theme_enable(void);
 
 /**
  * @brief Eval sizing.
@@ -177,7 +198,7 @@ EOAPI Eina_Bool  elm_obj_layout_theme_enable(void);
  *
  * @ingroup Elm_Layout
  */
-EOAPI void  elm_obj_layout_sizing_eval(void);
+EOAPI void elm_obj_layout_sizing_eval(void);
 
 /**
  * @brief Remove a child of the given part box.
@@ -192,7 +213,7 @@ EOAPI void  elm_obj_layout_sizing_eval(void);
  *
  * @ingroup Elm_Layout
  */
-EOAPI Evas_Object * elm_obj_layout_box_remove(const char *part, Evas_Object *child);
+EOAPI Evas_Object *elm_obj_layout_box_remove(const char *part, Evas_Object *child);
 
 /**
  * @brief Request sizing reevaluation, restricted to current width and/or
@@ -209,7 +230,7 @@ EOAPI Evas_Object * elm_obj_layout_box_remove(const char *part, Evas_Object *chi
  *
  * @ingroup Elm_Layout
  */
-EOAPI void  elm_obj_layout_sizing_restricted_eval(Eina_Bool width, Eina_Bool height);
+EOAPI void elm_obj_layout_sizing_restricted_eval(Eina_Bool width, Eina_Bool height);
 
 /**
  * @brief Sets a specific cursor style for an edje part.
@@ -221,7 +242,7 @@ EOAPI void  elm_obj_layout_sizing_restricted_eval(Eina_Bool width, Eina_Bool hei
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_part_cursor_style_set(const char *part_name, const char *style);
+EOAPI Eina_Bool elm_obj_layout_part_cursor_style_set(const char *part_name, const char *style);
 
 /**
  * @brief Get a specific cursor style for an edje part.
@@ -233,25 +254,7 @@ EOAPI Eina_Bool  elm_obj_layout_part_cursor_style_set(const char *part_name, con
  *
  * @ingroup Elm_Layout
  */
-EOAPI const char * elm_obj_layout_part_cursor_style_get(const char *part_name);
-
-/**
- * @brief Set the text of the given part.
- *
- * @param[in] text The text to set.
- *
- * @ingroup Elm_Layout
- */
-EOAPI Eina_Bool  elm_obj_layout_text_set(const char *part, const char *text);
-
-/**
- * @brief Get the text set in the given part.
- *
- * @param[in] part The TEXT part to retrieve the text off.
- *
- * @ingroup Elm_Layout
- */
-EOAPI const char * elm_obj_layout_text_get(const char *part);
+EOAPI const char *elm_obj_layout_part_cursor_style_get(const char *part_name);
 
 /**
  * @brief Add a callback for a (Edje) signal emitted by a layout widget's
@@ -268,7 +271,7 @@ EOAPI const char * elm_obj_layout_text_get(const char *part);
  *
  * @ingroup Elm_Layout
  */
-EOAPI void  elm_obj_layout_signal_callback_add(const char *emission, const char *source, Edje_Signal_Cb func, void *data);
+EOAPI void elm_obj_layout_signal_callback_add(const char *emission, const char *source, Edje_Signal_Cb func, void *data);
 
 /**
  * @brief Sets a specific cursor for an edje part.
@@ -280,7 +283,7 @@ EOAPI void  elm_obj_layout_signal_callback_add(const char *emission, const char
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_part_cursor_set(const char *part_name, const char *cursor);
+EOAPI Eina_Bool elm_obj_layout_part_cursor_set(const char *part_name, const char *cursor);
 
 /**
  * @brief Get the cursor to be shown when mouse is over an edje part.
@@ -289,7 +292,7 @@ EOAPI Eina_Bool  elm_obj_layout_part_cursor_set(const char *part_name, const cha
  *
  * @ingroup Elm_Layout
  */
-EOAPI const char * elm_obj_layout_part_cursor_get(const char *part_name);
+EOAPI const char *elm_obj_layout_part_cursor_get(const char *part_name);
 
 /**
  * @brief Insert child to layout box part before a reference object.
@@ -304,7 +307,7 @@ EOAPI const char * elm_obj_layout_part_cursor_get(const char *part_name);
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_box_insert_before(const char *part, Evas_Object *child, const Evas_Object *reference);
+EOAPI Eina_Bool elm_obj_layout_box_insert_before(const char *part, Evas_Object *child, const Evas_Object *reference);
 
 /**
  * @brief Insert child to layout box part at a given position.
@@ -319,9 +322,9 @@ EOAPI Eina_Bool  elm_obj_layout_box_insert_before(const char *part, Evas_Object
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_box_insert_at(const char *part, Evas_Object *child, unsigned int pos);
+EOAPI Eina_Bool elm_obj_layout_box_insert_at(const char *part, Evas_Object *child, unsigned int pos);
 
-EOAPI Eina_Bool  elm_obj_layout_sub_object_add_enable(void);
+EOAPI Eina_Bool elm_obj_layout_sub_object_add_enable(void);
 
 /**
  * @brief Get the edje data from the given layout.
@@ -338,7 +341,7 @@ EOAPI Eina_Bool  elm_obj_layout_sub_object_add_enable(void);
  *
  * @ingroup Elm_Layout
  */
-EOAPI const char * elm_obj_layout_data_get(const char *key);
+EOAPI const char *elm_obj_layout_data_get(const char *key);
 
 /**
  * @brief Append child to layout box part.
@@ -352,7 +355,7 @@ EOAPI const char * elm_obj_layout_data_get(const char *key);
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_box_append(const char *part, Evas_Object *child);
+EOAPI Eina_Bool elm_obj_layout_box_append(const char *part, Evas_Object *child);
 
 /**
  * @brief Remove a signal-triggered callback from a given layout widget.
@@ -372,7 +375,7 @@ EOAPI Eina_Bool  elm_obj_layout_box_append(const char *part, Evas_Object *child)
  *
  * @ingroup Elm_Layout
  */
-EOAPI void * elm_obj_layout_signal_callback_del(const char *emission, const char *source, Edje_Signal_Cb func);
+EOAPI void *elm_obj_layout_signal_callback_del(const char *emission, const char *source, Edje_Signal_Cb func);
 
 /**
  * @brief Thaws the Elementary object.
@@ -388,7 +391,7 @@ EOAPI void * elm_obj_layout_signal_callback_del(const char *emission, const char
  *
  * @ingroup Elm_Layout
  */
-EOAPI int  elm_obj_layout_thaw(void);
+EOAPI int elm_obj_layout_thaw(void);
 
 /**
  * @brief Prepend child to layout box part.
@@ -402,7 +405,7 @@ EOAPI int  elm_obj_layout_thaw(void);
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_box_prepend(const char *part, Evas_Object *child);
+EOAPI Eina_Bool elm_obj_layout_box_prepend(const char *part, Evas_Object *child);
 
 /**
  * @brief Send a (Edje) signal to a given layout widget's underlying Edje
@@ -416,7 +419,7 @@ EOAPI Eina_Bool  elm_obj_layout_box_prepend(const char *part, Evas_Object *child
  *
  * @ingroup Elm_Layout
  */
-EOAPI void  elm_obj_layout_signal_emit(const char *emission, const char *source);
+EOAPI void elm_obj_layout_signal_emit(const char *emission, const char *source);
 
 /**
  * @brief Insert child to layout table part.
@@ -440,7 +443,7 @@ EOAPI void  elm_obj_layout_signal_emit(const char *emission, const char *source)
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_table_pack(const char *part, Evas_Object *child, unsigned short col, unsigned short row, unsigned short colspan, unsigned short rowspan);
+EOAPI Eina_Bool elm_obj_layout_table_pack(const char *part, Evas_Object *child, unsigned short col, unsigned short row, unsigned short colspan, unsigned short rowspan);
 
 /**
  * @brief Unsets a cursor previously set with
@@ -451,7 +454,7 @@ EOAPI Eina_Bool  elm_obj_layout_table_pack(const char *part, Evas_Object *child,
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_part_cursor_unset(const char *part_name);
+EOAPI Eina_Bool elm_obj_layout_part_cursor_unset(const char *part_name);
 
 /**
  * @brief Remove all the child objects of the given part table.
@@ -465,25 +468,13 @@ EOAPI Eina_Bool  elm_obj_layout_part_cursor_unset(const char *part_name);
  *
  * @ingroup Elm_Layout
  */
-EOAPI Eina_Bool  elm_obj_layout_table_clear(const char *part, Eina_Bool clear);
+EOAPI Eina_Bool elm_obj_layout_table_clear(const char *part, Eina_Bool clear);
 
 EOAPI extern const Eo_Event_Description _ELM_LAYOUT_EVENT_THEME_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_LAYOUT_EVENT_LANGUAGE_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_LAYOUT_EVENT_ACCESS_CHANGED;
 
 /**
  * No description
  */
 #define ELM_LAYOUT_EVENT_THEME_CHANGED (&(_ELM_LAYOUT_EVENT_THEME_CHANGED))
 
-/**
- * No description
- */
-#define ELM_LAYOUT_EVENT_LANGUAGE_CHANGED (&(_ELM_LAYOUT_EVENT_LANGUAGE_CHANGED))
-
-/**
- * No description
- */
-#define ELM_LAYOUT_EVENT_ACCESS_CHANGED (&(_ELM_LAYOUT_EVENT_ACCESS_CHANGED))
-
 #endif
