@@ -24,25 +24,25 @@ EAPI const Eo_Class *elm_menu_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Menu
  */
-EOAPI Elm_Widget_Item * elm_obj_menu_selected_item_get(void);
+EOAPI Elm_Widget_Item *elm_obj_menu_selected_item_get(void);
 
 /** Returns a list of the item's items.
  *
  * @ingroup Elm_Menu
  */
-EOAPI const Eina_List * elm_obj_menu_items_get(void);
+EOAPI const Eina_List *elm_obj_menu_items_get(void);
 
 /** Get the first item in the menu.
  *
  * @ingroup Elm_Menu
  */
-EOAPI Elm_Widget_Item * elm_obj_menu_first_item_get(void);
+EOAPI Elm_Widget_Item *elm_obj_menu_first_item_get(void);
 
 /** Get the last item in the menu.
  *
  * @ingroup Elm_Menu
  */
-EOAPI Elm_Widget_Item * elm_obj_menu_last_item_get(void);
+EOAPI Elm_Widget_Item *elm_obj_menu_last_item_get(void);
 
 /**
  * @brief Move the menu to a new position
@@ -55,7 +55,7 @@ EOAPI Elm_Widget_Item * elm_obj_menu_last_item_get(void);
  *
  * @ingroup Elm_Menu
  */
-EOAPI void  elm_obj_menu_move(Evas_Coord x, Evas_Coord y);
+EOAPI void elm_obj_menu_move(Evas_Coord x, Evas_Coord y);
 
 /**
  * @brief Add an item at the end of the given menu widget.
@@ -72,7 +72,7 @@ EOAPI void  elm_obj_menu_move(Evas_Coord x, Evas_Coord y);
  *
  * @ingroup Elm_Menu
  */
-EOAPI Elm_Widget_Item * elm_obj_menu_item_add(Elm_Widget_Item *parent, const char *icon, const char *label, Evas_Smart_Cb func, const void *data);
+EOAPI Elm_Widget_Item *elm_obj_menu_item_add(Elm_Widget_Item *parent, const char *icon, const char *label, Evas_Smart_Cb func, const void *data);
 
 /**
  * @brief Close a opened menu
@@ -81,7 +81,7 @@ EOAPI Elm_Widget_Item * elm_obj_menu_item_add(Elm_Widget_Item *parent, const cha
  *
  * @ingroup Elm_Menu
  */
-EOAPI void  elm_obj_menu_close(void);
+EOAPI void elm_obj_menu_close(void);
 
 /**
  * @brief Add a separator item to menu @c obj under @c parent.
@@ -92,24 +92,12 @@ EOAPI void  elm_obj_menu_close(void);
  *
  * @ingroup Elm_Menu
  */
-EOAPI Elm_Widget_Item * elm_obj_menu_item_separator_add(Elm_Widget_Item *parent);
+EOAPI Elm_Widget_Item *elm_obj_menu_item_separator_add(Elm_Widget_Item *parent);
 
-EOAPI extern const Eo_Event_Description _ELM_MENU_EVENT_LANGUAGE_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_MENU_EVENT_ACCESS_CHANGED;
 EOAPI extern const Eo_Event_Description _ELM_MENU_EVENT_DISMISSED;
 EOAPI extern const Eo_Event_Description _ELM_MENU_EVENT_ELM_ACTION_BLOCK_MENU;
 EOAPI extern const Eo_Event_Description _ELM_MENU_EVENT_ELM_ACTION_UNBLOCK_MENU;
 
-/**
- * No description
- */
-#define ELM_MENU_EVENT_LANGUAGE_CHANGED (&(_ELM_MENU_EVENT_LANGUAGE_CHANGED))
-
-/**
- * No description
- */
-#define ELM_MENU_EVENT_ACCESS_CHANGED (&(_ELM_MENU_EVENT_ACCESS_CHANGED))
-
 /**
  * No description
  */
