@@ -34,7 +34,7 @@ EAPI const Eo_Class *elm_progressbar_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI void  elm_obj_progressbar_span_size_set(Evas_Coord size);
+EOAPI void elm_obj_progressbar_span_size_set(Evas_Coord size);
 
 /**
  * @brief Control the (exact) length of the bar region of a given progress bar
@@ -53,7 +53,7 @@ EOAPI void  elm_obj_progressbar_span_size_set(Evas_Coord size);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI Evas_Coord  elm_obj_progressbar_span_size_get(void);
+EOAPI Evas_Coord elm_obj_progressbar_span_size_get(void);
 
 /**
  * @brief Control whether a given progress bar widget is at "pulsing mode" or
@@ -73,7 +73,7 @@ EOAPI Evas_Coord  elm_obj_progressbar_span_size_get(void);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI void  elm_obj_progressbar_pulse_set(Eina_Bool pulse);
+EOAPI void elm_obj_progressbar_pulse_set(Eina_Bool pulse);
 
 /**
  * @brief Control whether a given progress bar widget is at "pulsing mode" or
@@ -93,7 +93,7 @@ EOAPI void  elm_obj_progressbar_pulse_set(Eina_Bool pulse);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI Eina_Bool  elm_obj_progressbar_pulse_get(void);
+EOAPI Eina_Bool elm_obj_progressbar_pulse_get(void);
 
 /**
  * @brief Control the progress value (in percentage) on a given progress bar
@@ -108,7 +108,7 @@ EOAPI Eina_Bool  elm_obj_progressbar_pulse_get(void);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI void  elm_obj_progressbar_value_set(double val);
+EOAPI void elm_obj_progressbar_value_set(double val);
 
 /**
  * @brief Control the progress value (in percentage) on a given progress bar
@@ -123,7 +123,7 @@ EOAPI void  elm_obj_progressbar_value_set(double val);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI double  elm_obj_progressbar_value_get(void);
+EOAPI double elm_obj_progressbar_value_get(void);
 
 /**
  * @brief Invert a given progress bar widget's displaying values order
@@ -138,7 +138,7 @@ EOAPI double  elm_obj_progressbar_value_get(void);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI void  elm_obj_progressbar_inverted_set(Eina_Bool inverted);
+EOAPI void elm_obj_progressbar_inverted_set(Eina_Bool inverted);
 
 /**
  * @brief Invert a given progress bar widget's displaying values order
@@ -153,7 +153,7 @@ EOAPI void  elm_obj_progressbar_inverted_set(Eina_Bool inverted);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI Eina_Bool  elm_obj_progressbar_inverted_get(void);
+EOAPI Eina_Bool elm_obj_progressbar_inverted_get(void);
 
 /**
  * @brief Control the orientation of a given progress bar widget
@@ -166,7 +166,7 @@ EOAPI Eina_Bool  elm_obj_progressbar_inverted_get(void);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI void  elm_obj_progressbar_horizontal_set(Eina_Bool horizontal);
+EOAPI void elm_obj_progressbar_horizontal_set(Eina_Bool horizontal);
 
 /**
  * @brief Control the orientation of a given progress bar widget
@@ -179,7 +179,7 @@ EOAPI void  elm_obj_progressbar_horizontal_set(Eina_Bool horizontal);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI Eina_Bool  elm_obj_progressbar_horizontal_get(void);
+EOAPI Eina_Bool elm_obj_progressbar_horizontal_get(void);
 
 /**
  * @brief Control the format string for a given progress bar widget's units
@@ -199,7 +199,7 @@ EOAPI Eina_Bool  elm_obj_progressbar_horizontal_get(void);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI void  elm_obj_progressbar_unit_format_set(const char *units);
+EOAPI void elm_obj_progressbar_unit_format_set(const char *units);
 
 /**
  * @brief Control the format string for a given progress bar widget's units
@@ -219,7 +219,7 @@ EOAPI void  elm_obj_progressbar_unit_format_set(const char *units);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI const char * elm_obj_progressbar_unit_format_get(void);
+EOAPI const char *elm_obj_progressbar_unit_format_get(void);
 
 /**
  * @brief Set the format function pointer for the units label
@@ -236,7 +236,7 @@ EOAPI const char * elm_obj_progressbar_unit_format_get(void);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI void  elm_obj_progressbar_unit_format_function_set(progressbar_func_type func, progressbar_freefunc_type free_func);
+EOAPI void elm_obj_progressbar_unit_format_function_set(progressbar_func_type func, progressbar_freefunc_type free_func);
 
 /**
  * @brief Set the progress value (in percentage) on a given progress bar widget
@@ -250,7 +250,7 @@ EOAPI void  elm_obj_progressbar_unit_format_function_set(progressbar_func_type f
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI void  elm_obj_progressbar_part_value_set(const char *part, double val);
+EOAPI void elm_obj_progressbar_part_value_set(const char *part, double val);
 
 /**
  * @brief Get the progress value (in percentage) on a given progress bar widget
@@ -264,7 +264,7 @@ EOAPI void  elm_obj_progressbar_part_value_set(const char *part, double val);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI double  elm_obj_progressbar_part_value_get(const char *part);
+EOAPI double elm_obj_progressbar_part_value_get(const char *part);
 
 /**
  * @brief Start/stop a given progress bar "pulsing" animation, if its under
@@ -277,25 +277,13 @@ EOAPI double  elm_obj_progressbar_part_value_get(const char *part);
  *
  * @ingroup Elm_Progressbar
  */
-EOAPI void  elm_obj_progressbar_pulse(Eina_Bool state);
+EOAPI void elm_obj_progressbar_pulse(Eina_Bool state);
 
 EOAPI extern const Eo_Event_Description _ELM_PROGRESSBAR_EVENT_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_PROGRESSBAR_EVENT_LANGUAGE_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_PROGRESSBAR_EVENT_ACCESS_CHANGED;
 
 /**
  * No description
  */
 #define ELM_PROGRESSBAR_EVENT_CHANGED (&(_ELM_PROGRESSBAR_EVENT_CHANGED))
 
-/**
- * No description
- */
-#define ELM_PROGRESSBAR_EVENT_LANGUAGE_CHANGED (&(_ELM_PROGRESSBAR_EVENT_LANGUAGE_CHANGED))
-
-/**
- * No description
- */
-#define ELM_PROGRESSBAR_EVENT_ACCESS_CHANGED (&(_ELM_PROGRESSBAR_EVENT_ACCESS_CHANGED))
-
 #endif
